@@ -25,7 +25,7 @@ SHARED_COLUMN_NAMES = [
 
 BOX_SCORE_COLUMN_NAMES = ["slug", "name"] + SHARED_COLUMN_NAMES
 
-PLAYER_SEASON_BOX_SCORE_COLUMN_NAMES = ["date", "points_scored", "plus_minus"] + SHARED_COLUMN_NAMES
+PLAYER_SEASON_BOX_SCORE_COLUMN_NAMES = ["active", "date", "points_scored", "plus_minus"] + SHARED_COLUMN_NAMES
 
 SCHEDULE_COLUMN_NAMES = [
     "start_time",
